@@ -76,7 +76,7 @@ get_current_weather <-
            emit_latlon_msg = TRUE,
            as.data.table = FALSE) {
     # CRAN NOTE avoidance
-    JSONurl_site_list <- NULL # nocov
+    JSONurl_site_list <- end <- name <- NULL # nocov
 
     # Load JSON URL list
     load(system.file("extdata", "JSONurl_site_list.rda",  # nocov start
@@ -94,9 +94,6 @@ get_current_weather <-
       stopifnot(is.character(station_name),
                 length(station_name) == 1)
 
-      # CRAN NOTE avoidance
-      name <- NULL # nocov
-
       station_name <- toupper(station_name)
 
       # If there's an exact match, use it; else, attempt partial match.
