@@ -3,9 +3,11 @@
 #'
 #' Download the latest station locations and metadata and update bomrang's
 #' internal databases that support the use of \code{\link{get_current_weather}}
-#' and \code{\link{get_ag_bulletin}}.  There is no need to use this unless you
-#' know that a station exists in BOM's database that is not available in the
-#' databases distributed with \pkg{bomrang}.
+#' \code{\link{get_ag_bulletin}} and \code{\link{get_historical}}.  There is no
+#' need to use this unless you know that a station exists in BOM's database
+#' that is not available in the databases distributed with \pkg{bomrang}. In
+#' fact, for reproducibility purposes, users are discouraged from using this
+#' function.
 #'
 #' If \pkg{ASGS.foyer} is installed locally, this function will automatically
 #' check and correct any invalid state values for stations located in Australia.
@@ -28,20 +30,41 @@
 #' @export
 #'
 update_station_locations <- function() {
-  # CRAN NOTE avoidance
+
+  message(
+    "This will overwrite the current internal databases of BOM stations.\n",
+    "If reproducibility is necessary, you may not wish to proceed.\n",
+    "Do you understand and wish to proceed (Y/n)?\n")
+  
+  answer <-
+    readLines(con = getOption("bomrang_connection"), n = 1)
+  
+  answer <- toupper(answer)
+  
+  if (answer != "Y" & answer != "YES") {
+    stop("Station databases were not updated.",
+         call. = FALSE)
+  }
+  
+  message("Updating internal station databases.\n")
+  
+    # CRAN NOTE avoidance
   name <- site <- state_code <- wmo <- state <- lon <- lat <- # nocov start
-    actual_state <- state_from_latlon <- NULL # nocov end
+    actual_state <- state_from_latlon <- end <- NULL # nocov end
+  
   tryCatch({
     curl::curl_download(url =
-          "ftp://ftp2.bom.gov.au/anon2/home/ncc/metadata/sitelists/stations.zip",
+                          "ftp://ftp.bom.gov.au/anon2/home/ncc/metadata/sitelists/stations.zip",
                         destfile = file.path(tempdir(), "stations.zip"))
   },
   error = function(x)
     stop(
       "\nThe server with the location information is not responding.",
-      "Please retry again later.\n"
+      "Please retry again later.\n",
+      call. = FALSE
     ))
-
+  
+  
   bom_stations_raw <-
     readr::read_table(
       file.path(tempdir(), "stations.zip"),
@@ -56,7 +79,6 @@ update_station_locations <- function() {
         "lat",
         "lon",
         "NULL1",
-        "NULL2",
         "state",
         "elev",
         "bar_ht",
@@ -71,28 +93,25 @@ update_station_locations <- function() {
         lat = readr::col_double(),
         lon = readr::col_double(),
         NULL1 = readr::col_character(),
-        NULL2 = readr::col_character(),
         state = readr::col_character(),
         elev = readr::col_double(),
         bar_ht = readr::col_double(),
         wmo = readr::col_integer()
       )
     )
-
+  
   # remove extra columns for source of location
-  bom_stations_raw <- bom_stations_raw[, -c(8:9)]
-
+  bom_stations_raw <- bom_stations_raw[, -8]
+  
   # trim the end of the rows off that have extra info that's not in columns
-  nrows <- nrow(bom_stations_raw) - 6
-  bom_stations_raw <- bom_stations_raw[1:nrows,]
-
-  # return only current stations listing
-  bom_stations_raw <-
-    bom_stations_raw[is.na(bom_stations_raw$end),]
-  bom_stations_raw$end <- format(Sys.Date(), "%Y")
-
+  nrows <- nrow(bom_stations_raw) - 7
+  bom_stations_raw <- bom_stations_raw[1:nrows, ]
+  
+  # add current year to stations that are still active
+  bom_stations_raw$end[is.na(bom_stations_raw$end)] <-
+    format(Sys.Date(), "%Y")
+  
   # if sf is installed, correct the state column, otherwise skip
-
   if (requireNamespace("ASGS.foyer", quietly = TRUE)) {
     message(
       "The package 'ASGS.foyer' is installed. Station locations will\n",
@@ -107,7 +126,7 @@ update_station_locations <- function() {
                             yr = "2016",
                             return = "v")
     }
-
+    
     bom_stations_raw %>%
       .[lon > -50, state_from_latlon := latlon2state(lat, lon)] %>%
       .[state_from_latlon == "New South Wales", actual_state := "NSW"] %>%
@@ -122,10 +141,10 @@ update_station_locations <- function() {
       .[actual_state != state &
           state %notin% c("ANT", "ISL"), state := actual_state] %>%
       .[, actual_state := NULL]
-
+    
     data.table::setDF(bom_stations_raw)
   }
-
+  
   # recode the states to match product codes
   # IDD - NT,
   # IDN - NSW/ACT,
@@ -133,7 +152,7 @@ update_station_locations <- function() {
   # IDS - SA,
   # IDT - Tas/Antarctica,
   # IDV - Vic, IDW - WA
-
+  
   bom_stations_raw$state_code <- NA
   bom_stations_raw$state_code[bom_stations_raw$state == "WA"] <- "W"
   bom_stations_raw$state_code[bom_stations_raw$state == "QLD"] <-
@@ -147,7 +166,7 @@ update_station_locations <- function() {
   bom_stations_raw$state_code[bom_stations_raw$state == "NSW"] <-
     "N"
   bom_stations_raw$state_code[bom_stations_raw$state == "SA"] <- "S"
-
+  
   stations_site_list <-
     bom_stations_raw %>%
     dplyr::select(site:wmo, state, state_code) %>%
@@ -181,37 +200,40 @@ update_station_locations <- function() {
           )
       )
     )
-
+  
   # There are weather stations that do have a wmo but don't report online,
   # most of these don't have a "state" value, e.g., KIRIBATI NTC AWS or
   # MARSHALL ISLANDS NTC AWS, remove these from the list
-
+  
   JSONurl_site_list <-
     stations_site_list[!is.na(stations_site_list$url),]
-
+  
   JSONurl_site_list <-
     JSONurl_site_list %>%
     dplyr::rowwise() %>%
     dplyr::mutate(url = dplyr::if_else(httr::http_error(url),
                                        NA_character_,
                                        url))
-
+  
   # Remove new NA values from invalid URLs and convert to data.table
   JSONurl_site_list <-
     data.table::data.table(JSONurl_site_list[!is.na(JSONurl_site_list$url),])
-
+  
   message("Overwriting existing databases")
-
+  
   fname <- system.file("extdata", "JSONurl_site_list.rda",
                        package = "bomrang")
   save(JSONurl_site_list, file = fname, compress = "bzip2")
-
+  
   stations_site_list <-
     stations_site_list %>%
-    dplyr::select(-state_code, -url)
+    dplyr::select(-state_code, -url) %>%
+    dplyr::filter(end == 2018) %>%
+    as.data.frame()
+  
   stations_site_list$site <-
     gsub("^0{1,2}", "", stations_site_list$site)
-
+  
   fname <-
     system.file("extdata", "stations_site_list.rda", package = "bomrang")
   save(stations_site_list, file = fname, compress = "bzip2")
