@@ -4,9 +4,8 @@ test_that("Error handling", {
   expect_error(get_historical(), regexp = "stationid.*latlon.*provided")
   expect_error(get_historical("sodiuhfosdhfoisdh"),
                regexp = "Station not recognised")
-  expect_error(get_historical(1), regexp = "Station not recognised.")
-  expect_error(get_historical("1"), regexp = "Station not recognised.")
-  expect_error(get_historical("023001"), regexp = "Station not recognised.")
+  expect_error(get_historical(2), regexp = "Station not recognised.")
+  expect_error(get_historical("2"), regexp = "Station not recognised.")
   expect_error(get_historical(latlon = 1), regexp = "2-element")
   expect_error(get_historical(latlon = c("a", "b")), regexp = "2-element")
   expect_warning(get_historical(stationid = "023000", latlon = c(1, 2)),
@@ -25,6 +24,16 @@ test_that("Query stationid = '023000',
   expect_equal(ADLhistrain$Station_number[1], 23000)
 })
 
+test_that("Query stationid = '023000',
+          meta == TRUE returns a list with metadata and weather data", {
+            skip_on_cran()
+            ADLhistmax <- get_historical("023000", type = "max", meta = TRUE)
+            expect_is(ADLhistmax, "list")
+            expect_equal(length(ADLhistmax), 2)
+            expect_equal(names(ADLhistmax), c("meta", "historical_data"))
+            expect_equal(nrow(ADLhistmax[[1]]), 1)
+          })
+
 test_that("Query latlon = c(-34.9285, 138.6007),
           type = 'rain' returns data.frame w/ correct station and some data", {
   skip_on_cran()
